/*
 * This file is part of the nivo project.
 *
 * Copyright 2016-present, Raphaël Benitte.
 *
 * For the full copyright and license information, please view the LICENSE
 * file that was distributed with this source code.
 */
import React from 'react';
import PropTypes from 'prop-types';
import pure from 'recompose/pure';
import { arc as d3Arc } from 'd3-shape';
import TableTooltip from '../../tooltip/TableTooltip';

var Chip = function Chip(_ref) {
    var color = _ref.color;
    return React.createElement('span', { style: { display: 'block', width: '12px', height: '12px', background: color } });
};

var RadarStackedTooltips = function RadarStackedTooltips(_ref2) {
    var data = _ref2.data,
        keys = _ref2.keys,
        getIndex = _ref2.getIndex,
        colorByKey = _ref2.colorByKey,
        radius = _ref2.radius,
        angleStep = _ref2.angleStep,
        theme = _ref2.theme,
        showTooltip = _ref2.showTooltip,
        hideTooltip = _ref2.hideTooltip;

    var arc = d3Arc().outerRadius(radius).innerRadius(0);

    var halfAngleStep = angleStep * 0.5;
    var rootStartAngle = -halfAngleStep;

    return React.createElement(
        'g',
        null,
        data.map(function (d, i) {
            var index = getIndex(d);
            var startAngle = rootStartAngle;
            var endAngle = startAngle + angleStep;

            rootStartAngle += angleStep;

            var rows = keys.map(function (key) {
                return [React.createElement(Chip, { color: colorByKey[key] }), key, d[key]];
            });

            var show = function show(e) {
                showTooltip(React.createElement(TableTooltip, { title: index, rows: rows, theme: theme }), e);
            };

            return React.createElement(
                'g',
                null,
                React.createElement('line', null),
                React.createElement('path', {
                    key: index,
                    d: arc({
                        startAngle: startAngle,
                        endAngle: endAngle
                    }),
                    fill: '#000',
                    fillOpacity: 0,
                    onMouseEnter: show,
                    onMouseMove: show,
                    onMouseLeave: hideTooltip
                })
            );
        })
    );
};

RadarStackedTooltips.propTypes = {
    data: PropTypes.array.isRequired,
    keys: PropTypes.arrayOf(PropTypes.oneOfType([PropTypes.string, PropTypes.number])).isRequired,
    getIndex: PropTypes.func.isRequired,
    colorByKey: PropTypes.object.isRequired,

    radius: PropTypes.number.isRequired,
    angleStep: PropTypes.number.isRequired,

    theme: PropTypes.object.isRequired,

    showTooltip: PropTypes.func.isRequired,
    hideTooltip: PropTypes.func.isRequired
};

export default pure(RadarStackedTooltips);