/*
 * This file is part of the nivo project.
 *
 * Copyright 2016-present, Raphaël Benitte.
 *
 * For the full copyright and license information, please view the LICENSE
 * file that was distributed with this source code.
 */
import React from 'react';
import PropTypes from 'prop-types';
import withPropsOnChange from 'recompose/withPropsOnChange';
import compose from 'recompose/compose';
import pure from 'recompose/pure';
import { arc as d3Arc } from 'd3-shape';
import TableTooltip from '../../tooltip/TableTooltip';

var Chip = function Chip(_ref) {
    var color = _ref.color;
    return React.createElement('span', { style: { display: 'block', width: '12px', height: '12px', background: color } });
};

var RadarStackedTooltipsItem = function RadarStackedTooltipsItem(_ref2) {
    var data = _ref2.data,
        keys = _ref2.keys,
        path = _ref2.path,
        colorByKey = _ref2.colorByKey,
        radius = _ref2.radius,
        angleStep = _ref2.angleStep,
        theme = _ref2.theme,
        showTooltip = _ref2.showTooltip,
        hideTooltip = _ref2.hideTooltip;

    var arc = d3Arc().outerRadius(radius).innerRadius(0);

    var rootStartAngle = angleStep * -0.5;

    return React.createElement(
        'g',
        null,
        data.map(function (d, i) {
            var index = getIndex(d);
            var startAngle = rootStartAngle;
            var endAngle = startAngle + angleStep;

            rootStartAngle += angleStep;

            var rows = keys.map(function (key) {
                return [React.createElement(Chip, { color: colorByKey[key] }), key, d[key]];
            });

            var show = function show(e) {
                showTooltip(React.createElement(TableTooltip, { rows: rows, theme: theme }), e);
            };

            return React.createElement('path', {
                key: index,
                d: arc({
                    startAngle: startAngle,
                    endAngle: endAngle
                }),
                fill: '#000',
                fillOpacity: 0,
                onMouseEnter: show,
                onMouseMove: show,
                onMouseLeave: hideTooltip
            });
        })
    );
};

RadarStackedTooltipsItem.propTypes = {
    datum: PropTypes.oneOfType([PropTypes.object, PropTypes.array]).isRequired,
    keys: PropTypes.arrayOf(PropTypes.oneOfType([PropTypes.string, PropTypes.number])).isRequired,
    index: PropTypes.oneOfType([PropTypes.string, PropTypes.number]),
    colorByKey: PropTypes.object.isRequired,

    startAngle: PropTypes.number.isRequired,
    endAngle: PropTypes.number.isRequired,
    radius: PropTypes.number.isRequired,

    theme: PropTypes.object.isRequired,

    showTooltip: PropTypes.func.isRequired,
    hideTooltip: PropTypes.func.isRequired
};

var enhance = compose(pure);

export default enhance(RadarStackedTooltipsItem);