var _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; };

/*
 * This file is part of the nivo project.
 *
 * Copyright 2016-present, Raphaël Benitte.
 *
 * For the full copyright and license information, please view the LICENSE
 * file that was distributed with this source code.
 */
import { pack as Pack } from 'd3-hierarchy';

/**
 * Computing bubble chart positions.
 * It's used for all Bubble related chart components.
 *
 * @param {number}   width
 * @param {number}   height
 * @param {object}   _root
 * @param {boolean}  leavesOnly
 * @param {function} getIdentity
 * @param {number}   padding
 * @param {function} getColor
 * @returns {array}
 */
export var computeBubble = function computeBubble(_ref) {
    var width = _ref.width,
        height = _ref.height,
        _root = _ref.root,
        leavesOnly = _ref.leavesOnly,
        getIdentity = _ref.getIdentity,
        padding = _ref.padding,
        getColor = _ref.getColor;

    var pack = Pack();
    pack.size([width, height]).padding(padding);

    var root = pack(_root);

    var nodes = leavesOnly ? root.leaves() : root.descendants();

    return nodes.map(function (d) {
        d.color = getColor(_extends({}, d.data, { depth: d.depth }));
        // if (d.depth > 1) {
        //     d.color = color(d.parentId)
        // } else {
        //     d.color = color(identity(d.data))
        // }

        d.data.key = d.ancestors().map(function (a) {
            return getIdentity(a.data);
        }).join('.');

        return d;
    });
};